
# This file was generated by 'versioneer.py' (0.28) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-05-11T23:54:55+0100",
 "dirty": false,
 "error": null,
 "full-revisionid": "bfa7f348455293d29286892ef45714d88a4e67d7",
 "version": "0.0.8.dev20230707"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
